summaryrefslogtreecommitdiff
path: root/test/unit/context/cdo_black.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/context/cdo_black.cpp')
-rw-r--r--test/unit/context/cdo_black.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/unit/context/cdo_black.cpp b/test/unit/context/cdo_black.cpp
index 16d7949e0..033e60f57 100644
--- a/test/unit/context/cdo_black.cpp
+++ b/test/unit/context/cdo_black.cpp
@@ -9,9 +9,9 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::context::CDO<>.
**
** Black box testing of CVC4::context::CDO<>.
**/
#include <iostream>
@@ -22,7 +22,7 @@
#include "context/cdo.h"
#include "test_context.h"
-namespace CVC4 {
+namespace CVC5 {
using namespace context;
@@ -48,4 +48,4 @@ TEST_F(TestContextBlackCDO, cdo)
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,9 +9,9 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::context::CDO<>.
+ ** \brief Black box testing of CVC5::context::CDO<>.
**
@@ -9,9 +9,9 @@
**
- ** Black box testing of CVC4::context::CDO<>.
+ ** Black box testing of CVC5::context::CDO<>.
**/
#include <iostream>